@@ -25,6 +25,7 @@
 #include "config.h"
 #endif
 
+#include <stdio.h>
 #define NEED_EVENTS
 #include <X11/X.h>
 #include <X11/Xproto.h>
@@ -35,7 +36,6 @@
 #include "xf86Xinput.h"
 #include "xf86_OSproc.h"
 #include "xf86OSmouse.h"
-#include "xf86_ansic.h"
 #include "mouse.h"
 #include "mousePriv.h"
 
